"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.apply = exports.name = void 0;
const koishi_1 = require("koishi");
exports.name = 'mowned';
const URL_BASE = 'https://mowned.com';
const URL_SEARCH = URL_BASE + '/api/phone/search?text=';
const URL_IMAGE = URL_BASE + '/html/phones/big/';
const URL_USER = URL_BASE + '/api/showcase/';
const URL_AVATAR = 'https://www.gravatar.com/avatar/';
function apply(ctx) {
    ctx.i18n.define('zh', require('./locales/zh'));
    const dataMap2Array = (data) => {
        const arr = [];
        if (!data)
            return arr;
        Object.keys(data).forEach(key => {
            if (key !== "success" && key !== "uid") {
                arr.push(data[key]);
            }
        });
        return arr;
    };
    ctx.command('mowned <model>', '搜索手机型号')
        .example("mownded 'Nokia 6230i'")
        .example("mownded -u mahoo12138")
        .option("user", "-u <username:string> 查询指定用户的手机列表")
        .action(async ({ session, options }, model) => {
        if (options.user) {
            try {
                const { userPhones, user: userInfo } = await ctx.http
                    .get(URL_USER + options.user);
                if (userPhones.length === 0) {
                    return session.text("user-never-add-phones", [options.user]);
                }
                const profile = koishi_1.segment.image(URL_AVATAR + userInfo.gravatar) + userInfo.fullName;
                const phonesList = userPhones.map(({ yearFrom: from, yearTo: to, phone: { name } }) => ` ·${from}~${to === 0 ? session.text('mowned.now') : to}：${name}`);
                return profile + session.text("mowned.phones", phonesList);
            }
            catch (e) {
                ctx.logger('mowned').warn(e);
                return session.text("mowned.user-not-exist", [options.user]);
            }
        }
        else {
            const info = await ctx.http.get(URL_SEARCH + model).then(dataMap2Array);
            let models = info.map(item => item?.search), answer = "1", index = 1;
            if (info.length >= 2) {
                await session.send(session.text("mowned.models", Object.fromEntries(models.slice(0, 4).map((v, i) => [i + 1, v]))));
                answer = await session.prompt(30 * 1000);
                if (!answer)
                    return;
            }
            else {
                if (info.length == 0)
                    return session.text('mowned.model-not-exist', [model]);
            }
            index = +answer - 1;
            if (!(0, koishi_1.isInteger)(index) || index < 0 || index >= 4) {
                return session.text('mowned.incorrect-index');
            }
            return koishi_1.segment.image(URL_IMAGE + info[index].image) + info[index].search;
        }
    });
}
exports.apply = apply;
